@@ -12,6 +12,7 @@
 Application class implementation.
 """
 
+
 # type annotations
 from __future__ import annotations
 from typing import List, Dict, Callable, NamedTuple, Type, TypeVar
@@ -24,6 +25,9 @@ import logging
 from . import cli
 from .config import Namespace
 
+# public interface
+__all__ = ['exit_status', 'Application', 'ApplicationGroup', 'CompletedCommand', ]
+
 
 TApp = TypeVar('TApp', bound='Application')
 TAppGrp = TypeVar('TAppGrp', bound='ApplicationGroup')
@@ -67,6 +71,18 @@ class Application(abc.ABC):
     log_critical: Callable[[str], None] = log.critical
     log_exception: Callable[[str], None] = log.exception
 
+    @classmethod
+    def handle_help(cls, message: str) -> None:
+        print(message)
+
+    @classmethod
+    def handle_version(cls, *args) -> None:
+        print(*args)
+
+    @classmethod
+    def handle_usage(cls, message: str) -> None:
+        print(message)
+
     def __init__(self, **parameters) -> None:
         """Direct initialization sets `parameters`."""
         for name, value in parameters.items():
@@ -96,7 +112,7 @@ class Application(abc.ABC):
                 if hasattr(cls, 'ALLOW_NOARGS') and cls.ALLOW_NOARGS is True:
                     pass
                 else:
-                    print(cls.interface.usage_text)
+                    cls.handle_usage(cls.interface.usage_text)
                     return exit_status.usage
 
             with cls.from_cmdline(cmdline) as app:
@@ -107,11 +123,11 @@ class Application(abc.ABC):
             return exit_status.success
 
         except cli.HelpOption as help_text:
-            print(help_text)
+            cls.handle_help(help_text)
             return exit_status.success
 
         except cli.VersionOption as version:
-            print(*version.args)
+            cls.handle_version(*version.args)
             return exit_status.success
 
         except cli.ArgumentError as error:
@@ -149,11 +165,11 @@ class CompletedCommand(Exception):
 
 class ApplicationGroup(Application):
     """
-    A group entry-point delegates to member `Applications`.
+    A group entry-point delegates to member `Application`.
     """
 
     interface: cli.Interface = None
-    commands: Dict[str, Application] = None
+    commands: Dict[str, Type[Application]] = None
     command: str = None
 
     ALLOW_PARSE: bool = False
@@ -167,19 +183,19 @@ class ApplicationGroup(Application):
     def from_cmdline(cls: Type[TAppGrp], cmdline: List[str] = None) -> TAppGrp:
         """Initialize via command-line arguments (e.g., `sys.argv`)."""
         if not cmdline:
-            return super().from_cmdline(cmdline)  # noqa: FIXME: typing
+            return super(ApplicationGroup, cls).from_cmdline(cmdline)
         else:
             if cls.ALLOW_PARSE is True and not any(arg in cmdline for arg in {'-h', '--help'}):
                 known, remainder = cls.interface.parse_known_intermixed_args(cmdline)
-                self = super().from_namespace(known)
+                self = super(ApplicationGroup, cls).from_namespace(known)
                 self.cmdline = remainder
                 self.shared = Namespace(vars(known))
                 self.shared.pop('command')
             else:
                 first, *remainder = cmdline
-                self = super().from_cmdline([first, ])
+                self = super(ApplicationGroup, cls).from_cmdline([first, ])
                 self.cmdline = list(remainder)
-            return self  # noqa: FIXME: typing
+            return self
 
     def run(self) -> None:
         """Delegate to member application."""
